@@ -795,21 +795,16 @@ disp("PASSED dynamic array of pointers access");
 
 ## check 'tm' struct conversions
 disp("checking 'tm' struct conversions ...");
-gps = 989168284;
-utc = [2011, 5, 11, 16, 57, 49, 4, 131, 0];
-assert(all(XLALGPSToUTC(gps) == utc));
-assert(XLALUTCToGPS(utc) == gps);
-assert(XLALUTCToGPS(utc(1:6)) == gps);
-utc(7) = utc(8) = 0;
-for i = [-1, 0, 1]
-  utc(9) = i;
-  assert(XLALUTCToGPS(utc) == gps);
-endfor
-utcd = utc;
+gps0 = 989168284;
+utc0 = [2011, 5, 11, 16, 57, 49];
+assert(all(XLALGPSToUTC(gps0) == utc0));
+assert(XLALUTCToGPS(utc0) == gps0);
 for i = 0:9
-  utcd(3) = utc(3) + i;
-  utcd = XLALGPSToUTC(XLALUTCToGPS(utcd));
-  assert(utcd(7) == weekday(datenum(utcd(1:6))));
+  gps = gps0 + i * 86400;
+  utc = utc0;
+  utc(3) = utc(3) + i;
+  assert(all(XLALGPSToUTC(gps) == utc));
+  assert(XLALUTCToGPS(utc) == gps);
 endfor
 LALCheckMemoryLeaks();
 disp("PASSED 'tm' struct conversions");
@@ -840,9 +835,13 @@ assert(t1 - t2 == 5.5 && strcmp(swig_type(t1 - t2), "LIGOTimeGPS"));
 assert(t1 * t2 == 52.5 && strcmp(swig_type(t1 * t2), "LIGOTimeGPS"));
 assert(t2 * t1 == 52.5 && strcmp(swig_type(t2 * t1), "LIGOTimeGPS"));
 assert(t1 / t2 == 2.1 && strcmp(swig_type(t1 / t2), "LIGOTimeGPS"));
-assert(t1 > t2 && t2 < t1 && t1 >= t2 && t2 <= t1)
-assert(LIGOTimeGPS(333333333,333333333) == LIGOTimeGPS(1000000000) / 3)
-assert(LIGOTimeGPS(666666666,666666667) == LIGOTimeGPS(2000000000) / 3)
+assert(t1 > t2 && t2 < t1 && t1 >= t2 && t2 <= t1);
+assert(LIGOTimeGPS(333333333,333333333) == LIGOTimeGPS(1000000000) / 3);
+assert(LIGOTimeGPS(666666666,666666667) == LIGOTimeGPS(2000000000) / 3);
+assert(LIGOTimeGPS("-62997760.825036067") == LIGOTimeGPS("-47044285.062262587") - LIGOTimeGPS("15953475.76277348"));
+assert(LIGOTimeGPS("-6542354.389038577") == LIGOTimeGPS("-914984.929117316") * 7.1502318572066237);
+assert(LIGOTimeGPS("-6542354.389038577") == 7.1502318572066237 * LIGOTimeGPS("-914984.929117316"));
+assert(LIGOTimeGPS("-127965.770535834") == LIGOTimeGPS("-914984.929117316") / 7.1502318572066237);
 t1 += 812345667.75;
 assert(strcmp(t1.__str__(), "812345678.250000000"));
 assert(new_LIGOTimeGPS(t1.__repr__()) == t1);
@@ -852,6 +851,7 @@ t4struct.t = 1234.5;
 assert(t4struct.t == 1234.5);
 t5 = LIGOTimeGPS("1000");
 assert(t5 == 1000);
+disp("*** below should be error messages from LIGOTimeGPS constructor ***");
 try
   t5 = LIGOTimeGPS("abc1000");
   expected_exception = 1;
@@ -862,6 +862,7 @@ try
   expected_exception = 1;
 end_try_catch
 assert(!expected_exception);
+disp("*** above should be error messages from LIGOTimeGPS constructor ***");
 assert(swig_lal_test_noptrgps(LIGOTimeGPS(1234.5)) == swig_lal_test_noptrgps(1234.5))
 clear t0;
 clear t1;
